Run bazel build by default

Change-Id: Ia68ae6e38cabe5b6d948c5ccee2987c0f7c25a70
diff --git a/TestON/tests/dependencies/ONOSSetup.py b/TestON/tests/dependencies/ONOSSetup.py
index 8879220..63a5b9c 100644
--- a/TestON/tests/dependencies/ONOSSetup.py
+++ b/TestON/tests/dependencies/ONOSSetup.py
@@ -286,14 +286,14 @@
     def buildOnos( self, cluster ):
         """
         Description:
             build the onos using buck build onos and verify the result
         Required:
             * cluster - the cluster driver that will be used.
         Returns:
             Returns main.TRUE if it successfully built.
         """
         main.step( "Creating ONOS package" )
-        packageResult = main.ONOSbench.buckBuild()
+        packageResult = main.ONOSbench.bazelBuild()
         utilities.assert_equals( expect=main.TRUE,
                                  actual=packageResult,
                                  onpass="Successfully created ONOS package",
@@ -286,14 +286,14 @@
         """
         Description:
-            build the onos using buck build onos and verify the result
+            build the onos using bazel build onos and verify the result
         Required:
             * cluster - the cluster driver that will be used.